@@ -6,7 +6,7 @@ use tracing::warn;
 use yazi_shared::env_exists;
 
 use super::{Iterm2, Kitty, KittyOld};
-use crate::{Chafa, Emulator, Sixel, Ueberzug, SHOWN, TMUX};
+use crate::{Chafa, Emulator, Sixel, Ueberzug, SHOWN, TMUX, WSL};
 
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
 pub enum Adapter {
@@ -82,8 +82,13 @@ impl Adapter {
 
 impl Adapter {
 	pub fn matches() -> Self {
-		let mut protocols = Emulator::detect().adapters();
+		let emulator = Emulator::detect();
+		#[cfg(windows)]
+		if matches!(emulator, Emulator::Microsoft) {
+			return Self::Sixel;
+		}
 
+		let mut protocols = emulator.adapters();
 		#[cfg(windows)]
 		protocols.retain(|p| *p == Self::Iterm2);
 		if env_exists("ZELLIJ_SESSION_NAME") {
@@ -95,18 +100,20 @@ impl Adapter {
 			return *p;
 		}
 
+		let supported_compositor = Ueberzug::supported_compositor();
 		match env::var("XDG_SESSION_TYPE").unwrap_or_default().as_str() {
 			"x11" => return Self::X11,
-			"wayland" => return Self::Wayland,
+			"wayland" if supported_compositor => return Self::Wayland,
+			"wayland" if !supported_compositor => warn!("[Adapter] Unsupported Wayland compositor"),
 			_ => warn!("[Adapter] Could not identify XDG_SESSION_TYPE"),
 		}
-		if env_exists("WAYLAND_DISPLAY") {
+		if supported_compositor && env_exists("WAYLAND_DISPLAY") {
 			return Self::Wayland;
 		}
 		if env_exists("DISPLAY") {
 			return Self::X11;
 		}
-		if std::fs::symlink_metadata("/proc/sys/fs/binfmt_misc/WSLInterop").is_ok() {
+		if *WSL {
 			return Self::KittyOld;
 		}
 
