@@ -22,10 +22,10 @@ pub struct Fetcher {
 
 impl Fetcher {
 	#[inline]
-	pub fn matches(&self, path: &Path, mime: Option<&str>, f: impl Fn(&str) -> bool + Copy) -> bool {
+	pub fn matches(&self, path: &Path, mime: &str, f: impl Fn(&str) -> bool + Copy) -> bool {
 		self.if_.as_ref().and_then(|c| c.eval(f)) != Some(false)
-			&& (self.mime.as_ref().zip(mime).map_or(false, |(p, m)| p.match_mime(m))
-				|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == Some(MIME_DIR))))
+			&& (self.mime.as_ref().is_some_and(|p| p.match_mime(mime))
+				|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == MIME_DIR)))
 	}
 }
 
