@@ -1,7 +1,7 @@
 use serde::{Deserialize, Deserializer};
-use yazi_shared::fs::File;
+use yazi_shared::{fs::File, theme::{Color, Style, StyleShadow}};
 
-use super::{Color, Is, Style, StyleShadow};
+use super::Is;
 use crate::Pattern;
 
 pub struct Filetype {
@@ -12,13 +12,13 @@ pub struct Filetype {
 }
 
 impl Filetype {
-	pub fn matches(&self, file: &File, mime: Option<&str>) -> bool {
+	pub fn matches(&self, file: &File, mime: &str) -> bool {
 		if !self.is.check(&file.cha) {
 			return false;
 		}
 
-		self.name.as_ref().is_some_and(|n| n.match_path(&file.url, file.is_dir()))
-			|| self.mime.as_ref().zip(mime).map_or(false, |(m, s)| m.matches(s))
+		self.mime.as_ref().is_some_and(|p| p.match_mime(mime))
+			|| self.name.as_ref().is_some_and(|n| n.match_path(&file.url, file.is_dir()))
 	}
 }
 
