@@ -1,11 +1,10 @@
-use std::path::PathBuf;
+use std::{path::PathBuf, str::FromStr};
 
 use serde::{Deserialize, Serialize};
 use validator::Validate;
 use yazi_shared::{fs::expand_path, theme::Style, Xdg};
 
-use super::{Filetype, Flavor, Icon};
-use crate::{validation::check_validation, MERGED_THEME};
+use super::{Filetype, Flavor, Icons};
 
 #[derive(Deserialize, Serialize)]
 pub struct Theme {
@@ -23,16 +22,17 @@ pub struct Theme {
 	// File-specific styles
 	#[serde(rename = "filetype", deserialize_with = "Filetype::deserialize", skip_serializing)]
 	pub filetypes: Vec<Filetype>,
-	#[serde(rename = "icon", deserialize_with = "Icon::deserialize", skip_serializing)]
-	pub icons:     Vec<Icon>,
+	#[serde(rename = "icon", skip_serializing)]
+	pub icons:     Icons,
 }
 
-impl Default for Theme {
-	fn default() -> Self {
-		let mut theme: Self = toml::from_str(&MERGED_THEME).unwrap();
+impl FromStr for Theme {
+	type Err = anyhow::Error;
 
-		check_validation(theme.manager.validate());
-		check_validation(theme.which.validate());
+	fn from_str(s: &str) -> Result<Self, Self::Err> {
+		let mut theme: Self = toml::from_str(s)?;
+		theme.manager.validate()?;
+		theme.which.validate()?;
 
 		if theme.flavor.use_.is_empty() {
 			theme.manager.syntect_theme = expand_path(&theme.manager.syntect_theme);
@@ -41,7 +41,7 @@ impl Default for Theme {
 				Xdg::config_dir().join(format!("flavors/{}.yazi/tmtheme.xml", theme.flavor.use_));
 		}
 
-		theme
+		Ok(theme)
 	}
 }
 
