@@ -5,9 +5,8 @@ use crate::manager::Manager;
 impl Manager {
 	pub fn suspend(&mut self, _: Cmd) {
 		#[cfg(unix)]
-		tokio::spawn(async move {
-			yazi_proxy::AppProxy::stop().await;
-			unsafe { libc::raise(libc::SIGTSTP) };
-		});
+		unsafe {
+			libc::raise(libc::SIGTSTP);
+		}
 	}
 }
