@@ -5,7 +5,7 @@ use crate::tab::Tab;
 impl Tab {
 	pub fn linemode(&mut self, mut c: Cmd) {
 		render!(self.conf.patch(|new| {
-			let Some(mode) = c.take_first() else {
+			let Some(mode) = c.take_first_str() else {
 				return;
 			};
 			if !mode.is_empty() && mode.len() <= 20 {
