@@ -8,9 +8,9 @@ pub struct Opt {
 }
 
 impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
+	fn from(mut c: Cmd) -> Self {
 		Self {
-			state: match c.named.get("state").map(|s| s.as_str()) {
+			state: match c.take_str("state").as_deref() {
 				Some("true") => Some(true),
 				Some("false") => Some(false),
 				_ => None,
@@ -28,7 +28,7 @@ impl Tab {
 		let (removal, addition): (Vec<_>, Vec<_>) = match opt.into().state {
 			Some(true) => (vec![], iter.collect()),
 			Some(false) => (iter.collect(), vec![]),
-			None => iter.partition(|&u| self.selected.contains(u)),
+			None => iter.partition(|&u| self.selected.contains_key(u)),
 		};
 
 		let same = !self.current.cwd.is_search();
