@@ -4,6 +4,7 @@ mod config;
 mod finder;
 mod mode;
 mod preview;
+mod selected;
 mod tab;
 
 pub use backstack::*;
@@ -11,4 +12,5 @@ pub use config::*;
 pub use finder::*;
 pub use mode::*;
 pub use preview::*;
+pub use selected::*;
 pub use tab::*;
