@@ -19,10 +19,10 @@ impl App {
 		let collision = COLLISION.swap(false, Ordering::Relaxed);
 		let frame = term
 			.draw(|f| {
-				_ = Lives::scope(&self.cx, |_| Ok(f.render_widget(Root::new(&self.cx), f.size())));
+				_ = Lives::scope(&self.cx, |_| Ok(f.render_widget(Root::new(&self.cx), f.area())));
 
-				if let Some((x, y)) = self.cx.cursor() {
-					f.set_cursor(x, y);
+				if let Some(pos) = self.cx.cursor() {
+					f.set_cursor_position(pos);
 				}
 			})
 			.unwrap();
@@ -51,10 +51,10 @@ impl App {
 
 		let frame = term
 			.draw_partial(|f| {
-				f.render_widget(crate::notify::Layout::new(&self.cx), f.size());
+				f.render_widget(crate::notify::Layout::new(&self.cx), f.area());
 
-				if let Some((x, y)) = self.cx.cursor() {
-					f.set_cursor(x, y);
+				if let Some(pos) = self.cx.cursor() {
+					f.set_cursor_position(pos);
 				}
 			})
 			.unwrap();
@@ -69,20 +69,20 @@ impl App {
 		let mut new = Buffer::empty(frame.area);
 		for y in new.area.top()..new.area.bottom() {
 			for x in new.area.left()..new.area.right() {
-				let cell = frame.buffer.get(x, y);
+				let cell = &frame.buffer[(x, y)];
 				if cell.skip {
-					*new.get_mut(x, y) = cell.clone();
+					new[(x, y)] = cell.clone();
 				}
-				new.get_mut(x, y).set_skip(!cell.skip);
+				new[(x, y)].set_skip(!cell.skip);
 			}
 		}
 
 		let patches = frame.buffer.diff(&new);
 		let mut backend = CrosstermBackend::new(BufWriter::new(stderr().lock()));
 		backend.draw(patches.into_iter()).ok();
-		if let Some((x, y)) = cursor {
+		if let Some(pos) = cursor {
 			backend.show_cursor().ok();
-			backend.set_cursor(x, y).ok();
+			backend.set_cursor_position(pos).ok();
 		}
 		backend.flush().ok();
 	}
