@@ -1,6 +1,6 @@
-use yazi_shared::{event::Cmd, term::Term};
+use yazi_shared::event::Cmd;
 
-use crate::app::App;
+use crate::{app::App, Term};
 
 impl App {
 	pub(crate) fn resume(&mut self, _: Cmd) {
@@ -11,6 +11,6 @@ impl App {
 		// We need to trigger a resize, and render the UI based on the resized area.
 		self.resize(());
 
-		self.signals.resume();
+		self.signals.resume(None);
 	}
 }
