@@ -1,4 +1,4 @@
-use yazi_config::{keymap::{Control, Key}, KEYMAP};
+use yazi_config::{keymap::{Chord, Key}, KEYMAP};
 use yazi_shared::{emit, Layer};
 
 use crate::app::App;
@@ -31,6 +31,8 @@ impl<'a> Router<'a> {
 			self.matches(Layer::Help, key)
 		} else if cx.input.visible {
 			self.matches(Layer::Input, key)
+		} else if cx.confirm.visible {
+			self.matches(Layer::Confirm, key)
 		} else if cx.select.visible {
 			self.matches(Layer::Select, key)
 		} else if cx.tasks.visible {
@@ -42,13 +44,13 @@ impl<'a> Router<'a> {
 
 	#[inline]
 	fn matches(&mut self, layer: Layer, key: Key) -> bool {
-		for ctrl @ Control { on, .. } in KEYMAP.get(layer) {
+		for ctrl @ Chord { on, .. } in KEYMAP.get(layer) {
 			if on.is_empty() || on[0] != key {
 				continue;
 			}
 
 			if on.len() > 1 {
-				self.app.cx.which.show_with(&key, layer);
+				self.app.cx.which.show_with(key, layer);
 			} else {
 				emit!(Seq(ctrl.to_seq(), layer));
 			}
