@@ -14,7 +14,7 @@ impl<'a> Select<'a> {
 impl<'a> Widget for Select<'a> {
 	fn render(self, _: Rect, buf: &mut Buffer) {
 		let select = &self.cx.select;
-		let area = self.cx.area(&select.position);
+		let area = self.cx.manager.area(select.position);
 
 		let items: Vec<_> = select
 			.window()
