@@ -53,9 +53,13 @@ function M:seek(units)
 end
 
 function M:fallback_to_builtin()
-	local _, bound = ya.preview_code(self)
+	local err, bound = ya.preview_code(self)
 	if bound then
 		ya.manager_emit("peek", { bound, only_if = self.file.url, upper_bound = true })
+	elseif err and not err:find("cancelled", 1, true) then
+		ya.preview_widgets(self, {
+			ui.Paragraph(self.area, { ui.Line(err):reverse() }),
+		})
 	end
 end
 
