@@ -26,14 +26,14 @@ impl<'a> TryFrom<mlua::Table<'a>> for Position {
 				x:      t.raw_get("x").unwrap_or_default(),
 				y:      t.raw_get("y").unwrap_or_default(),
 				width:  t.raw_get("w")?,
-				height: 3,
+				height: t.raw_get("h").unwrap_or(3),
 			},
 		}))
 	}
 }
 
-impl<'lua> IntoLua<'lua> for Position {
-	fn into_lua(self, lua: &'lua mlua::Lua) -> mlua::Result<mlua::Value> {
+impl IntoLua<'_> for Position {
+	fn into_lua(self, lua: &mlua::Lua) -> mlua::Result<mlua::Value> {
 		lua
 			.create_table_from([
 				(1.into_lua(lua)?, self.origin.to_string().into_lua(lua)?),
