@@ -10,7 +10,7 @@ impl<'lua, T> IntoLua<'lua> for Range<T>
 where
 	T: IntoLua<'lua>,
 {
-	fn into_lua(self, lua: &'lua mlua::Lua) -> mlua::Result<mlua::Value> {
+	fn into_lua(self, lua: &'lua mlua::Lua) -> mlua::Result<mlua::Value<'lua>> {
 		lua.create_sequence_from([self.0.start, self.0.end])?.into_lua(lua)
 	}
 }
