@@ -2,7 +2,7 @@ use mlua::AnyUserData;
 
 use crate::elements::Renderable;
 
-pub fn cast_to_renderable(ud: AnyUserData) -> Option<Box<dyn Renderable + Send>> {
+pub fn cast_to_renderable(ud: &AnyUserData) -> Option<Box<dyn Renderable + Send>> {
 	if let Ok(c) = ud.take::<crate::elements::Paragraph>() {
 		Some(Box::new(c))
 	} else if let Ok(c) = ud.take::<crate::elements::List>() {
