@@ -2,6 +2,7 @@ use std::mem;
 
 use ansi_to_tui::IntoText;
 use mlua::{AnyUserData, ExternalError, ExternalResult, FromLua, IntoLua, Lua, Table, UserData, UserDataMethods, Value};
+use unicode_width::UnicodeWidthChar;
 
 use super::{Span, Style};
 
@@ -84,7 +85,7 @@ impl UserData for Line {
 	fn add_methods<'lua, M: UserDataMethods<'lua, Self>>(methods: &mut M) {
 		crate::impl_style_shorthands!(methods, 0.style);
 
-		methods.add_function("width", |_, ud: AnyUserData| Ok(ud.borrow_mut::<Self>()?.0.width()));
+		methods.add_method("width", |_, me, ()| Ok(me.0.width()));
 		methods.add_function("style", |_, (ud, value): (AnyUserData, Value)| {
 			{
 				let mut me = ud.borrow_mut::<Self>()?;
@@ -105,5 +106,8 @@ impl UserData for Line {
 			});
 			Ok(ud)
 		});
+		methods.add_method("visible", |_, me, ()| {
+			Ok(me.0.iter().flat_map(|s| s.content.chars()).any(|c| c.width().unwrap_or(0) > 0))
+		});
 	}
 }
