@@ -1,4 +1,5 @@
 use mlua::{AnyUserData, ExternalError, FromLua, Lua, Table, UserData, UserDataMethods, Value};
+use unicode_width::UnicodeWidthChar;
 
 use super::Style;
 
@@ -29,5 +30,8 @@ impl UserData for Span {
 			};
 			Ok(ud)
 		});
+		methods.add_method("visible", |_, me, ()| {
+			Ok(me.0.content.chars().any(|c| c.width().unwrap_or(0) > 0))
+		});
 	}
 }
