@@ -1,10 +1,10 @@
-use std::{io::Cursor, mem, path::{Path, PathBuf}, sync::atomic::{AtomicUsize, Ordering}};
+use std::{borrow::Cow, io::Cursor, mem, path::{Path, PathBuf}, sync::atomic::{AtomicUsize, Ordering}};
 
 use anyhow::{anyhow, Result};
-use ratatui::text::{Line, Span, Text};
+use ratatui::{layout::Rect, text::{Line, Span, Text}};
 use syntect::{dumps, easy::HighlightLines, highlighting::{self, Theme, ThemeSet}, parsing::{SyntaxReference, SyntaxSet}, LoadingError};
 use tokio::{fs::File, io::{AsyncBufReadExt, BufReader}, sync::OnceCell};
-use yazi_config::{PREVIEW, THEME};
+use yazi_config::{preview::PreviewWrap, PREVIEW, THEME};
 use yazi_shared::PeekError;
 
 static INCR: AtomicUsize = AtomicUsize::new(0);
@@ -38,46 +38,28 @@ impl Highlighter {
 		(&r.0, &r.1)
 	}
 
-	async fn find_syntax(path: &Path) -> Result<&'static SyntaxReference> {
-		let (_, syntaxes) = Self::init().await;
-		let name = path.file_name().map(|n| n.to_string_lossy()).unwrap_or_default();
-		if let Some(s) = syntaxes.find_syntax_by_extension(&name) {
-			return Ok(s);
-		}
+	#[inline]
+	pub fn abort() { INCR.fetch_add(1, Ordering::Relaxed); }
 
-		let ext = path.extension().map(|e| e.to_string_lossy()).unwrap_or_default();
-		if let Some(s) = syntaxes.find_syntax_by_extension(&ext) {
-			return Ok(s);
-		}
-
-		let mut line = String::new();
-		let mut reader = BufReader::new(File::open(&path).await?);
-		reader.read_line(&mut line).await?;
-		syntaxes.find_syntax_by_first_line(&line).ok_or_else(|| anyhow!("No syntax found"))
-	}
-
-	pub async fn highlight(&self, skip: usize, limit: usize) -> Result<Text<'static>, PeekError> {
+	pub async fn highlight(&self, skip: usize, area: Rect) -> Result<Text<'static>, PeekError> {
 		let mut reader = BufReader::new(File::open(&self.path).await?);
 
 		let syntax = Self::find_syntax(&self.path).await;
-		let mut plain = syntax.is_err() as u8;
+		let mut plain = syntax.is_err();
 
-		let mut before = Vec::with_capacity(if plain == 0 { skip } else { 0 });
-		let mut after = Vec::with_capacity(limit);
+		let mut before = Vec::with_capacity(if plain { 0 } else { skip });
+		let mut after = Vec::with_capacity(area.height as _);
 
 		let mut i = 0;
 		let mut buf = vec![];
-		while reader.read_until(b'\n', &mut buf).await.is_ok() {
-			i += 1;
-			if buf.is_empty() || i > skip + limit {
-				break;
+		let mut inspected = 0u16;
+		while reader.read_until(b'\n', &mut buf).await.is_ok_and(|n| n > 0) {
+			if Self::is_binary(&buf, &mut inspected) {
+				return Err("Binary file".into());
 			}
 
-			if plain == 0 && buf.len() > 5000 {
-				plain = 1;
-				drop(mem::take(&mut before));
-			} else if plain == 0 && buf.contains(&0x1b) {
-				plain = 2;
+			if !plain && (buf.len() > 5000 || buf.contains(&0x1b)) {
+				plain = true;
 				drop(mem::take(&mut before));
 			}
 
@@ -87,27 +69,34 @@ impl Highlighter {
 				buf.push(b'\n');
 			}
 
-			if i > skip {
+			i += if i >= skip {
+				buf.iter_mut().for_each(Self::carriage_return_to_line_feed);
 				after.push(String::from_utf8_lossy(&buf).into_owned());
-			} else if plain == 0 {
+				Self::line_height(&after[after.len() - 1], area.width)
+			} else if !plain {
 				before.push(String::from_utf8_lossy(&buf).into_owned());
-			}
+				Self::line_height(&before[before.len() - 1], area.width)
+			} else if PREVIEW.wrap == PreviewWrap::Yes {
+				Self::line_height(&String::from_utf8_lossy(&buf), area.width)
+			} else {
+				1
+			};
+
 			buf.clear();
+			if i > skip + area.height as usize {
+				break;
+			}
 		}
 
-		if skip > 0 && i < skip + limit {
-			return Err(PeekError::Exceed(i.saturating_sub(limit)));
+		if skip > 0 && i < skip + area.height as usize {
+			return Err(PeekError::Exceed(i.saturating_sub(area.height as _)));
 		}
 
-		if plain == 0 {
-			Self::highlight_with(before, after, syntax.unwrap()).await
-		} else if plain == 1 {
-			Ok(Text::from(after.join("").replace('\t', &PREVIEW.indent())))
-		} else if plain == 2 {
-			Ok(Text::from(after.join("").replace('\x1b', "^[").replace('\t', &PREVIEW.indent())))
+		Ok(if plain {
+			Text::from(after.join("").replace('\x1b', "^[").replace('\t', &PREVIEW.indent()))
 		} else {
-			unreachable!()
-		}
+			Self::highlight_with(before, after, syntax.unwrap()).await?
+		})
 	}
 
 	async fn highlight_with(
@@ -143,13 +132,100 @@ impl Highlighter {
 		.await?
 	}
 
-	#[inline]
-	pub fn abort() { INCR.fetch_add(1, Ordering::Relaxed); }
+	async fn find_syntax(path: &Path) -> Result<&'static SyntaxReference> {
+		let (_, syntaxes) = Self::init().await;
+		let name = path.file_name().map(|n| n.to_string_lossy()).unwrap_or_default();
+		if let Some(s) = syntaxes.find_syntax_by_extension(&name) {
+			return Ok(s);
+		}
+
+		let ext = path.extension().map(|e| e.to_string_lossy()).unwrap_or_default();
+		if let Some(s) = syntaxes.find_syntax_by_extension(&ext) {
+			return Ok(s);
+		}
+
+		let mut line = String::new();
+		let mut reader = BufReader::new(File::open(&path).await?);
+		reader.read_line(&mut line).await?;
+		syntaxes.find_syntax_by_first_line(&line).ok_or_else(|| anyhow!("No syntax found"))
+	}
+
+	#[inline(always)]
+	fn is_binary(buf: &[u8], inspected: &mut u16) -> bool {
+		if let Some(n) = 1024u16.checked_sub(*inspected) {
+			*inspected += n.min(buf.len() as u16);
+			buf.iter().take(n as usize).any(|&b| b == 0)
+		} else {
+			false
+		}
+	}
+
+	fn line_height(s: &str, width: u16) -> usize {
+		if PREVIEW.wrap != PreviewWrap::Yes {
+			return 1;
+		}
+
+		let pad = PREVIEW
+			.tab_size
+			.checked_sub(1)
+			.map(|n| s.bytes().filter(|&b| b == b'\t').count() * n as usize)
+			.map(|n| yazi_config::preview::Preview::indent_with(n))
+			.unwrap_or_default();
+
+		let line = Line {
+			spans: vec![Span { content: pad, style: Default::default() }, Span {
+				content: Cow::Borrowed(s),
+				..Default::default()
+			}],
+			..Default::default()
+		};
+
+		ratatui::widgets::Paragraph::new(line)
+			.wrap(ratatui::widgets::Wrap { trim: false })
+			.line_count(width)
+	}
+
+	#[inline(always)]
+	fn carriage_return_to_line_feed(c: &mut u8) {
+		if *c == b'\r' {
+			*c = b'\n';
+		}
+	}
 }
 
 impl Highlighter {
+	pub fn to_line_widget(regions: Vec<(highlighting::Style, &str)>, indent: &str) -> Line<'static> {
+		let spans: Vec<_> = regions
+			.into_iter()
+			.map(|(style, s)| {
+				let mut modifier = ratatui::style::Modifier::empty();
+				if style.font_style.contains(highlighting::FontStyle::BOLD) {
+					modifier |= ratatui::style::Modifier::BOLD;
+				}
+				if style.font_style.contains(highlighting::FontStyle::ITALIC) {
+					modifier |= ratatui::style::Modifier::ITALIC;
+				}
+				if style.font_style.contains(highlighting::FontStyle::UNDERLINE) {
+					modifier |= ratatui::style::Modifier::UNDERLINED;
+				}
+
+				Span {
+					content: s.replace('\t', indent).into(),
+					style:   ratatui::style::Style {
+						fg: Self::to_ansi_color(style.foreground),
+						// bg: Self::to_ansi_color(style.background),
+						add_modifier: modifier,
+						..Default::default()
+					},
+				}
+			})
+			.collect();
+
+		Line::from(spans)
+	}
+
 	// Copy from https://github.com/sharkdp/bat/blob/master/src/terminal.rs
-	pub fn to_ansi_color(color: highlighting::Color) -> Option<ratatui::style::Color> {
+	fn to_ansi_color(color: highlighting::Color) -> Option<ratatui::style::Color> {
 		if color.a == 0 {
 			// Themes can specify one of the user-configurable terminal colors by
 			// encoding them as #RRGGBBAA with AA set to 00 (transparent) and RR set
@@ -187,34 +263,4 @@ impl Highlighter {
 			Some(ratatui::style::Color::Rgb(color.r, color.g, color.b))
 		}
 	}
-
-	pub fn to_line_widget(regions: Vec<(highlighting::Style, &str)>, indent: &str) -> Line<'static> {
-		let spans: Vec<_> = regions
-			.into_iter()
-			.map(|(style, s)| {
-				let mut modifier = ratatui::style::Modifier::empty();
-				if style.font_style.contains(highlighting::FontStyle::BOLD) {
-					modifier |= ratatui::style::Modifier::BOLD;
-				}
-				if style.font_style.contains(highlighting::FontStyle::ITALIC) {
-					modifier |= ratatui::style::Modifier::ITALIC;
-				}
-				if style.font_style.contains(highlighting::FontStyle::UNDERLINE) {
-					modifier |= ratatui::style::Modifier::UNDERLINED;
-				}
-
-				Span {
-					content: s.replace('\t', indent).into(),
-					style:   ratatui::style::Style {
-						fg: Self::to_ansi_color(style.foreground),
-						// bg: Self::to_ansi_color(style.background),
-						add_modifier: modifier,
-						..Default::default()
-					},
-				}
-			})
-			.collect();
-
-		Line::from(spans)
-	}
 }
