@@ -1,19 +1,29 @@
 use std::ops::ControlFlow;
 
+use md5::{Digest, Md5};
 use mlua::{Lua, Table};
 use unicode_width::UnicodeWidthChar;
 
 use super::Utils;
+use crate::CLIPBOARD;
 
 impl Utils {
 	pub(super) fn text(lua: &Lua, ya: &Table) -> mlua::Result<()> {
+		ya.raw_set(
+			"md5",
+			lua.create_async_function(|_, s: mlua::String| async move {
+				Ok(format!("{:x}", Md5::new_with_prefix(s.as_bytes()).finalize()))
+			})?,
+		)?;
+
 		ya.raw_set(
 			"quote",
-			lua.create_function(|_, s: mlua::String| {
-				#[cfg(unix)]
-				let s = shell_escape::unix::escape(s.to_str()?.into());
-				#[cfg(windows)]
-				let s = shell_escape::windows::escape(s.to_str()?.into());
+			lua.create_function(|_, (s, unix): (mlua::String, Option<bool>)| {
+				let s = match unix {
+					Some(true) => yazi_shared::shell::escape_unix(s.to_str()?),
+					Some(false) => yazi_shared::shell::escape_windows(s.to_str()?),
+					None => yazi_shared::shell::escape_native(s.to_str()?),
+				};
 				Ok(s.into_owned())
 			})?,
 		)?;
@@ -31,6 +41,18 @@ impl Utils {
 			})?,
 		)?;
 
+		ya.raw_set(
+			"clipboard",
+			lua.create_async_function(|lua, text: Option<String>| async move {
+				if let Some(text) = text {
+					CLIPBOARD.set(text).await;
+					Ok(None)
+				} else {
+					Some(lua.create_string(CLIPBOARD.get().await.as_encoded_bytes())).transpose()
+				}
+			})?,
+		)?;
+
 		Ok(())
 	}
 
