@@ -2,6 +2,8 @@
 
 mod op;
 mod process;
+mod shell;
 
 pub use op::*;
 pub use process::*;
+pub use shell::*;
