@@ -1,9 +1,11 @@
 #![allow(clippy::module_inception)]
 
 mod cmd;
+mod data;
 mod event;
 mod render;
 
 pub use cmd::*;
+pub use data::*;
 pub use event::*;
 pub use render::*;
